
# pypsea

[![Build Status](https://travis-ci.org/pyproteomics/pypsea.svg?branch=master)](https://travis-ci.org/pyproteomics/pypsea)
[![codecov](https://codecov.io/gh/pyproteomics/pypsea/branch/master/graph/badge.svg)](https://codecov.io/gh/pyproteomics/pypsea)


Protein Set Enrichment Analysis

## Installation

A typical installation requires the following commands to be run:

```bash
pip install pypsea
jupyter nbextension enable --py [--sys-prefix|--user|--system] pypsea
```

Or, if you use jupyterlab:

```bash
pip install pypsea
jupyter labextension install @jupyter-widgets/jupyterlab-manager
```
